#
# spec file for package python-flit-core
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname flit-core
%global flavor %{nil}
%define plainpython python
%if 0%{?suse_version} >= 1550
# The primary python flavor is built in Factory Ring0
%if "%{flavor}" == "primary"
%define pprefix %{primary_python}
%define pythons %{primary_python}
%endif
# Additional flavors are built in Factory Ring1
%if "%{flavor}" == ""
%define pprefix python
%{expand:%%define skip_%{primary_python} 1}
%if "%{shrink:%{pythons}}" == ""
# Exclude for local osc build: unresolvable
%define python_module() empty-python-buildset
# Exclude for obs server
ExclusiveArch:  do-not-build
%endif
%endif
%else
# backport and option d projects for 15.X having one or more python in the buildset don't need the Ring split for bootstrap
%if "%{flavor}" == "primary"
%define python_module() invalid-multibuild-flavor-for-15.X
ExclusiveArch:  do-not-build
%else
%define pprefix python
%endif
%endif
# test everything in the buildset by standard python flavor expansion: primary and non-primary, if any.
%if "%{flavor}" == "test"
%define pprefix python
%define psuffix -test
%endif
%{?sle15_python_module_pythons}
Name:           %{pprefix}-flit-core%{?psuffix}
Version:        3.9.0
Release:        2.2
Summary:        Distribution-building parts of Flit
License:        BSD-3-Clause AND MIT
URL:            https://github.com/pypa/flit
Source0:        https://files.pythonhosted.org/packages/source/f/flit_core/flit_core-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if "%{flavor}" == "test"
BuildRequires:  %{python_module flit-core = %{version}}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module testpath}
%endif
# SECTION boo#1186870
# We are a transitive build dependency of python-packaging
# which is used by pythondistdeps.py normally creating these entries
#!BuildIgnore:  %{primary_python}-packaging
#!BuildIgnore:  python3-packaging
Requires:       %{plainpython}(abi) = %{python_version}
Provides:       %{plainpython}%{python_version}dist(%{modname}) = %{version}
%if "%{python_flavor}" == "python3" || "%{python_provides}" == "python3"
Provides:       %{plainpython}3-%{modname} = %{version}-%{release}
Provides:       %{plainpython}3dist(%{modname}) = %{version}
Obsoletes:      %{plainpython}3-%{modname} < %{version}-%{release}
%endif
# /SECTION
%python_subpackages

%description
This provides a PEP 517 build backend for packages using Flit.
The only public interface is the API specified by PEP 517, at flit_core.buildapi.

%prep
%setup -q -n flit_core-%{version}

%if "%{flavor}" != "test"
%build
# https://flit.readthedocs.io/en/latest/bootstrap.html, take the first available python in the build set
mypython=%{expand:%%__%(echo %{pythons} | cut -d " " -f 1)}
$mypython -m flit_core.wheel

%install
%{python_expand #
mkdir -p %{buildroot}%{$python_sitelib}
$python bootstrap_install.py dist/flit_core-%{version}-py3-none-any.whl -i %{buildroot}%{$python_sitelib}
# Don't package the tests
rm -r  %{buildroot}%{$python_sitelib}/flit_core/tests
}
%{?python_compileall}
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if "%{flavor}" == "test"
%check
# make sure we do not test the sources but the package
rm flit_core/*.py pyproject.toml
%pytest -rfEs
%endif

%if "%{flavor}" != "test"
%files %{python_files}
%{python_sitelib}/flit_core
%{python_sitelib}/flit_core-%{version}*-info
%endif

%changelog
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use newly supported shrink{} on OBS to exclude python flavors
  will all python versions skipped.
* Thu Sep  7 2023 Dirk Müller <dmueller@suse.com>
- update to 3.9.0:
  * New options :option:`flit build --use-vcs` and :option:`flit
    build --no-use-vcs` to enable & disable including all
    committed files in the sdist. For now --use-vcs is the
    default, but this is likely to change in a
    future version, to bring flit build in line with standard
    build frontends like python -m build
  * Sdist file names, and the name of the top-level folder in an
    sdist, are now normalised, in accordance with PEP 625
  * A statically defined version number can now be parsed from
    files called version.py, _version.py or __version__.py inside
    a packge, as well as from __init__.py, so executing code is
    required in fewer cases
  * Fix setting the flag for regular files in zip metadata
  * The timestamp embedded in the gzip wrapper for sdists now
    defaults to a fixed date, so building an sdist twice on the
    same machine should produce identical results, even without
    any special steps.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sat Feb 11 2023 Ben Greiner <code@bnavigator.de>
- Require python independent of python-rpm-packaging being there
  to create the entry automatically
* Fri Feb 10 2023 Ben Greiner <code@bnavigator.de>
- Don't use :primary multibuild flavor for non-Tumbleweed
  * accomodates special SLE15 projects defininig extra flavors but
    not building for primary python3
* Fri Jan 27 2023 Antonio Larrosa <alarrosa@suse.com>
- Exclude the regular build in SLE15 SP5 as in SP4 instead of
  leaving it as unresolvable
* Tue Nov  8 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v3.8.0
  * Merge pull request #607 from pypa/relnotes-3.8
    Add release notes for version 3.8
  * Add --only-deps option to release notes
  * Merge pull request #546 from dciborow/dciborow/install-reqs
    Add "install-reqs" command to CLI
  * Fix some remaining uses of tomli in the tests, for Python 3.11
  * Remove test with side effects
  * Replace install-reqs subcommand with --only-deps option
  * Merge pull request #581 from nanonyme/nanonyme/bytecode
  * Merge pull request #602 from Mariatta/patch-1
    Document that token-based upload is supported
  * Merge pull request #604 from gotmax23/tomli
    Remove vestigial tomli usage
  * Test on Python 3.11-dev
  * Add python 3.11 to the test matrix
  * Adjust test deps in tox.ini
  * tests: Only use tomli if tomllib is missing
  * Fallback to installed tomli when vendor is removed
    In Fedora, we bootstrap tomli differently, so we remove the vendored
    version. This makes it so we don't also have to patch flit_core.config
    ourselves.
* Fri Oct  7 2022 Ben Greiner <code@bnavigator.de>
- Make sure the 15.4 tests also have python3-packaging
- Revert python_exec change, one pure wheel built by python3 is
  enough
* Fri Sep 30 2022 Dirk Müller <dmueller@suse.com>
- use the python_exec to bootstrap so that the primary interpeter
  is used
* Tue Aug  2 2022 Ben Greiner <code@bnavigator.de>
- Use prjconf provided primary_python if available
* Thu Jul 14 2022 Ben Greiner <code@bnavigator.de>
- Split primary flavor in multibuild for possible inclusion into
  Ring0
* Thu Jul 14 2022 Ben Greiner <code@bnavigator.de>
- Remove devendoring of tomli, so that we can put this in Ring0
* Fri Mar 25 2022 Ben Greiner <code@bnavigator.de>
- Update to version 3.7.1
  * Support for external data files such as man pages or Jupyter
    extension support files (PR #510).
  * Project names are now lowercase in wheel filenames and
    .dist-info folder names, in line with the specifications (PR
    [#498]).
  * Improved support for bootstrapping a Python environment, e.g.
    for downstream packagers (PR #511). flit_core.wheel is usable
    with python -m to create wheels before the build tool is
    available, and flit_core sdists also include a script to
    install itself from a wheel before installer is available.
  * Use newer importlib APIs, fixing some deprecation warnings (PR
    [#499]).
  * Fix building packages which need execution to get the version
    number, and have a relative import in __init__.py (PR #531).
- Update bootstrapping process
* Sun Jan  9 2022 Ben Greiner <code@bnavigator.de>
- Back to bootstrap without pip
* Sun Jan  9 2022 Ben Greiner <code@bnavigator.de>
- Update to version 3.6
  * flit_core now bundles the tomli TOML parser library (version
    1.2.3) to avoid a circular dependency between flit_core and
    tomli (:ghpull:`492`). This means flit_core now has no
    dependencies except Python itself, both at build time and at
    runtime, simplifying :doc:`bootstrapping <bootstrap>`.
- The above is not fully applicale to openSUSE, we debundle.
- Release notes for Version 3.5.1
  * Fix development installs with flit install --symlink and
  - -pth-file, which were broken in 3.5.0, especially for packages
    using a src folder (:ghpull:`472`).
- Release notes for Version 3.5
  * You can now use Flit to distribute a module or package inside a
    namespace package (as defined by PEP 420). To do this, specify
    the import name of the concrete, inner module you are packaging
  - e.g. name = "sphinxcontrib.foo" - either in the [project]
    table, or under [tool.flit.module] if you want to use a
    different name on PyPI (:ghpull:`468`).
  * Flit no longer generates a setup.py file in sdists (.tar.gz
    packages) by default (:ghpull:`462`). Modern packaging tools
    don't need this. You can use the --setup-py flag to keep adding
    it for now, but this will probably be removed at some point in
    the future.
  * Fixed how flit init handles authors' names with non-ASCII
    characters (:ghpull:`460`).
  * When flit init generates a LICENSE file, the new pyproject.toml
    now references it (:ghpull:`467`).
- Do not package tests
- Make it work with old python-rpm-macros
* Fri Oct 15 2021 Ben Greiner <code@bnavigator.de>
- Break build cycle by using upstream recommended bootstrap method
  https://flit.readthedocs.io/en/latest/bootstrap.html
* Fri Oct 15 2021 Ben Greiner <code@bnavigator.de>
- Update to Version 3.4
  * Python 3.6 or above is now required, both for flit and
    flit_core.
  * Add a --setup-py option to flit build and flit publish,
    and a warning when neither this nor --no-setup-py are
    specified (PR #431). A future version will stop
    generating setup.py files in sdists by default.
  * Add support for standardised editable installs - pip
    install -e - according to PEP 660 (PR #400).
  * Add a --pypirc option for flit publish to specify an
    alternative path to a .pypirc config file describing
    package indexes (PR #434).
  * Fix installing dependencies specified in a [project]
    table (PR #433)
  * Fix building wheels when SOURCE_DATE_EPOCH (see
    Reproducible builds) is set to a date before 1980 (PR
    [#448]).
  * Switch to using the tomli TOML parser, in common with
    other packaging projects (PR #438). This supports TOML
    version 1.0.
  * Add a document on Bootstrapping (PR #441).
- Release Version 3.3
  * PKG-INFO files in sdists are now generated the same way
    as METADATA in wheels, fixing some issues with sdists
    (PR #410).
  * flit publish now sends SHA-256 hashes, fixing uploads
    to GitLab package repositories (PR #416).
  * The [project] metadata table from PEP 621 is now fully
    supported and documented. Projects using this can now
    specify requires = ["flit_core >=3.2,<4"] in the
    [build-system] table.
- Multibuild: break another depcycle with
  pytest/importlib-metadata/tomli
* Wed Apr 14 2021 Matthias Bach <marix@marix.org>
- Update to version 3.2
  * Experimental support for specifying metadata in a [project] in
    pyproject.toml table as specified by PEP-621.
  * Fix writing METADATA file with multi-line information in
    certain fields such as Author.
  * Fix building wheel when a directory such as LICENSES appears
    in the project root directory.
  * Switch from the deprecated pytoml package to toml.
* Mon Oct 26 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 3.0
  * flit_core once again requires Python 3 (>=3.4). Packages that
    support Python 2 can still be built by flit_core 2.x, but can't
    rely on new features (:ghpull:`342`).
- Kill dephell dependency
* Mon Mar 23 2020 Matej Cepl <mcepl@suse.com>
- Add macro %%dephell_genspec to generate setup.py
* Sun Mar 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix generating with new dephell
* Wed Dec 18 2019 John Vandenberg <jayvdb@gmail.com>
- Remove dephell build workaround
* Mon Dec 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.1.0
